aboutsummaryrefslogtreecommitdiffstats
path: root/home/text_script.asm
diff options
context:
space:
mode:
authorSylvie <35663410+Rangi42@users.noreply.github.com>2024-09-18 21:01:18 -0400
committerGitHub <noreply@github.com>2024-09-18 21:01:18 -0400
commit613d34678b7e9da1a467ec48fff23bfa75209871 (patch)
treec21669899a90df25aaac9b4b4d213ac525d6f277 /home/text_script.asm
parentUse correct label in get_trainer_name.asm (#461) (diff)
downloadpokeyellow-613d34678b7e9da1a467ec48fff23bfa75209871.tar.gz
pokeyellow-613d34678b7e9da1a467ec48fff23bfa75209871.tar.xz
pokeyellow-613d34678b7e9da1a467ec48fff23bfa75209871.zip
Split `hSpriteIndexOrTextID` into `hSpriteIndex` and `hTextID` (#462)
Also identify `wPPUpCountAndMaxPP`
Diffstat (limited to 'home/text_script.asm')
-rw-r--r--home/text_script.asm9
1 files changed, 5 insertions, 4 deletions
diff --git a/home/text_script.asm b/home/text_script.asm
index 5c90a981..d367683d 100644
--- a/home/text_script.asm
+++ b/home/text_script.asm
@@ -1,6 +1,7 @@
; this function is used to display sign messages, sprite dialog, etc.
; INPUT: [hSpriteIndexOrTextID] = sprite ID or text ID
DisplayTextID::
+ assert hSpriteIndex == hTextID ; these are at the same memory location
ldh a, [hLoadedROMBank]
push af
farcall DisplayTextIDInit ; initialization
@@ -18,7 +19,7 @@ DisplayTextID::
ld h, [hl]
ld l, a ; hl = map text pointer
ld d, $00
- ldh a, [hSpriteIndexOrTextID] ; text ID
+ ldh a, [hTextID]
ld [wSpriteIndex], a
dict TEXT_START_MENU, DisplayStartMenu
@@ -29,7 +30,7 @@ DisplayTextID::
ld a, [wNumSprites]
ld e, a
- ldh a, [hSpriteIndexOrTextID] ; sprite ID
+ ldh a, [hSpriteIndex] ; sprite ID
cp e
jr z, .spriteHandling
jr nc, .skipSpriteHandling
@@ -42,7 +43,7 @@ DisplayTextID::
pop bc
pop de
ld hl, wMapSpriteData ; NPC text entries
- ldh a, [hSpriteIndexOrTextID]
+ ldh a, [hSpriteIndex]
dec a
add a
add l
@@ -1,6 +1,7 @@
; this function is used to display sign messages, sprite dialog, etc.
-; INPUT: [hSpriteIndexOrTextID] = sprite ID or text ID
+; INPUT: [hSpriteIndex] = sprite ID or [hTextID] = text ID
DisplayTextID::